@@ -17,6 +17,7 @@ from apscheduler.executors.base import BaseExecutor
 from apscheduler.executors.pool import ProcessPoolExecutor
 from apscheduler.job import Job
 from apscheduler.jobstores.memory import MemoryJobStore
+from apscheduler.schedulers.asyncio import AsyncIOScheduler
 from apscheduler.schedulers.background import BackgroundScheduler
 from apscheduler.triggers.base import BaseTrigger
 from apscheduler.triggers.interval import IntervalTrigger
@@ -80,7 +81,7 @@ class TaskIMessage(IMessage):
 
 class TaskExecutor(Worker, Generic[GenericDepContainer]):
     _tasks: Dict[str, Task]
-    _scheduler: BackgroundScheduler
+    _scheduler: BackgroundScheduler | AsyncIOScheduler
 
     def __init__(self, **kwargs):
         self._tasks = {}
@@ -95,7 +96,11 @@ class TaskExecutor(Worker, Generic[GenericDepContainer]):
             'coalesce': False,
             'max_instances': 10
         }
-        self._scheduler = BackgroundScheduler(jobstores={"default": MemoryJobStore()},
+        # self._scheduler = BackgroundScheduler(jobstores={"default": MemoryJobStore()},
+        #                                       executors=executors if executors else executor,
+        #                                       job_defaults=job_defaults if job_defaults else job_default,
+        #                                       timezone=utc)
+        self._scheduler = AsyncIOScheduler(jobstores={"default": MemoryJobStore()},
                                               executors=executors if executors else executor,
                                               job_defaults=job_defaults if job_defaults else job_default,
                                               timezone=utc)
@@ -137,6 +142,11 @@ class TaskExecutor(Worker, Generic[GenericDepContainer]):
                     task.scheduled_trigger = message.trigger
                     return
 
+        for task_id, task in self._tasks.copy().items():
+            if task.scheduled_job.func == message.task:
+                while not task.done_time:
+                    await asyncio.sleep(0.01)
+
         arc_task = Task(id=str(uuid.uuid4()),
                         name=message.task.__name__,
                         status="new",
