@@ -93,8 +93,9 @@ class ChainRequestHandler(ExtRequestHandler, Generic[GenericAppDepContainer]):
                         await plugin.exec_after(context=incoming, container=self.container, target_result=ret_val)
             else:
                 ret_val = await target(incoming, self.container)
+            if isinstance(ret_val, HTTPResponse):
+                return ret_val
             return self.response_fabric(ret_val)
-
         return f
 
 
