@@ -64,4 +64,4 @@ class AbstractApp(ABC, Generic[GenericDepContainer]):
         Func to run environment manually (without Runner)
         :return: None
         """
-        return await asyncio.wait(self.perform() + self.dispatcher.preform())
+        return await asyncio.wait(self.perform() + self.dispatcher.perform())
